<?php

namespace Ecommerce\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Doctrine\ORM\EntityManager;

class PedidoCotacaoController extends \Teknisa\Libs\Controller\CRUD {
    
    protected $dataSourceName;
    protected $parameterBagColumns;
    protected $connection;
    protected $service;
    protected $serviceEmail;
    protected $dataSourceManager;
    protected $zhFileUploader;
    protected $fileServerURL;
    protected $entityManager;
    
    
    public function __construct($crudService, $environment, $service, $serviceEmail, $connection, $dataSourceManager, $zhFileUploader, $fileServerURL, EntityManager $entityManager) {
		$this->crudService  = $crudService;
		$this->environment  = $environment;
        $this->service      = $service;
        $this->serviceEmail = $serviceEmail;
        $this->connection   = $connection;
        $this->dataSourceManager = $dataSourceManager;
        $this->zhFileUploader    = $zhFileUploader;
        $this->fileServerURL     = $fileServerURL;
        $this->entityManager = $entityManager;
	}

	public function salvarProdutos(DTO\Request $request, DTO\Response $response) {
        try {
            $request->setParameter('dbname', 'prmarcpedcol');
            parent::save($request, $response);
            $this->service->alterarHistnegociapcol($request, $response);
        } catch (\Exception $e){
            $response->setError(new Error($e->getMessage(), 1));
        }
	}
	
	public function salvarItempedcol(DTO\Request $request, DTO\Response $response) {
        try {
            $produtos = $request->getDataSet()->getRows();
            $condition = false;

            if (isset($produtos[0]["addCondition"])) {
                $condition = $produtos[0]["addCondition"];
            }

            foreach ($produtos as $produto) {
                $this->service->atualizaItempedcol($produto, $condition);
            }
        } catch (\Exception $e){
            $response->setError(new Error($e->getMessage(), 1));
        }
	}
	
	public function salvarComentario(DTO\Request $request, DTO\Response $response) {
       
        try {
            $row = $request->getRow();
            
            $row['DOCUMENTOANEXOFULLPATH'] = isset($row["fileUpload"]) && sizeof($row["fileUpload"]) ? $this->fileServerURL.$row["fileUpload"][0]["path"] : '';
            $result = $this->service->salvarComentario($request, $response);
            $this->serviceEmail->enviaEmailComentario($result, $row, $response);
        } catch (\Exception $e){
            $response->setError(new Error($e->getMessage(), 1));
        }
	}
	
    public function setFileFullPath(DTO\Request $request, DTO\Response $response) {
		$row = $request->getRow();
		if ($row["DSIDDOCFILESERV"] !== null) {
			$row["DOCUMENTOANEXOFULLPATH"] = $this->fileServerURL.$row["DSIDDOCFILESERV"];
		}
		$dataset = array(
            "row"   => $row
        );
        $response->addDataSet(new DataSet('data', $dataset));
	}
	
	private function logoSrc($response){
	    try {
			$sql = "SELECT URLLOGO FROM APPCONFIG WHERE IDAPLICATIVO = 'PORTAL E-COMMERCE' AND NRORG = :P_NRORG";
            $stmt = $this->connection->prepare($sql);
            $stmt->execute(
                array(
                    "P_NRORG" => $this->environment->getNrorgTrab()
                )
            );
			
			$result = $stmt->fetchAll();
			
			if(isset($result[0]) && $result[0]['URLLOGO'] && $result[0]['URLLOGO'] != null && $result[0]['URLLOGO'] != ''){
    			$logoSrc = $this->fileServerURL . $result[0]['URLLOGO'];
    			return $logoSrc;
	        }else{
	            return false;
	        }
		} catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), $e->getCode()));
		}
	}
	
	public function downloadFile(DTO\Request $request, DTO\Response $response) {
        $row = $request->getDataSet()->getRows()[0];
        $file = $row["DOCUMENTOANEXOFULLPATH"];
        $name = $row["DSDOCUMENTOANEXO"];
        $nameArray = explode(".", $name);
        $type = end($nameArray);
        header('Accept-Ranges: none');
        header("Content-Type: " . $type);
        header("Content-Disposition: attachment; filename=" . $name);
        readfile($file);
        exit;
    }
	
	public function savePrmarcpedcol(DTO\Request $request, DTO\Response $response) {
        try {
            $request->setParameter('dbname', 'prmarcpedcol');
            parent::save($request, $response);
        } catch (\Exception $e){
            $response->setError(new Error($e->getMessage(), 1));
        }
	}
	
	public function inserirItempedcol(DTO\Request\Row $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            $cdfilial = $row[0]['P_CDFILIAL'];
            $nrpedcoleta = $row[0]['P_NRPEDCOLETA'];
            $cdproduto = $row[0]['P_CDPRODUTO'];
            $cdmarca = $row[0]['P_CDMARCA'];
            $this->service->inserirItempedcol($cdfilial, $nrpedcoleta, $cdproduto, $cdmarca);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 1));
        }
    }
	
	public function atualizaValoresAlterados (DTO\Request $request, DTO\Response $response) {
        try {
            $this->service->atualizaValoresAlterados($request, $response);
        } catch (\Exception $e){
            $response->setError(new Error($e->getMessage(), 1));
        }
    }
    
	public function atualizaDesconto(DTO\Request $request, DTO\Response $response) {
        try {
            $this->service->atualizaDesconto($request, $response);
        } catch (\Exception $e){
            $response->setError(new Error($e->getMessage(), 1));
        }
	}
	
    public function retornaDados(DTO\Request $request, $response) {
		try {
		    $row = $request->getRow();
			$sql = "SELECT * FROM MOVOPITEMPEDCOL M WHERE M.CDFILIAL = :P_CDFILIAL AND M.CDFORNECED = :P_CDFORNECED AND M.CDMARCA = :P_CDMARCA AND M.CDPRODUTO = :P_CDPRODUTO AND NRORG = :NRORG AND NRPEDCOLETA IN (SELECT NRPEDCOLETA FROM PEDCOLETA WHERE NRPEDIDOCOL = :P_NRPEDIDOCOL)";
            $stmt = $this->connection->prepare($sql);
            $stmt->execute(
                array(
                    "P_CDFILIAL"    => $row['CDFILIAL'],
                    "P_CDFORNECED"  => $row['CDFORNECED'],
                    "P_CDMARCA"     => $row['CDMARCA'],
                    "P_CDPRODUTO"   => $row['CDPRODUTO'],
                    "P_NRPEDIDOCOL" => $row['NRPEDIDOCOL'],
                    "NRORG" => $this->environment->getNrorgTrab()
                )
            );
			$result = $stmt->fetchAll();
			$response->addDataset(new DataSet('movopitempedcol', $result));
		} catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), $e->getCode()));
		}
	}
	
	public function aceitaPedidoCotacao(DTO\Request $request, DTO\Response $response) {
	    $row = $request->getRow();
        try {
            $code = $this->service->ACEITA_PEDCOTWEB($request, $response);
            if ($code['P_IDACEITEOK'] === 'ERRO') {
                $this->service->alteraStatus($row, 'I');
            }else{
                $this->serviceEmail->enviaEmailPedidoAceito($request, $response);
            }
            $response->addDataSet(new DataSet ('idaceiteok', array($code['P_IDACEITEOK'])));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function recusaPedidoCotacao(DTO\Request $request, DTO\Response $response) {
        try {
            $request->setParameter('dbname', 'pedcolgeral');
            parent::save($request, $response);
            $this->serviceEmail->enviaEmailPedidoRecusado($request, $response);
        } catch (\Exception $e){
            $response->setError(new Error($e->getMessage(), 1));
        }
	}
	
	public function salvarMovopitempedcol(DTO\Request $request, DTO\Response $response) {
		try {
			$this->service->salvarMovopitempedcol($request, $response);
		} catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), $e->getCode()));
		}
	}
	
	public function verifyParamTermoAceite(DTO\Request $request, DTO\Response $response){
	    $row = $request->getRow();
	    try {
    	    $paramAceite = $this->service->returnParamTermoAceite($row['CDFORNECED']);
            $dataset = array(
                "PARAMACEITE"   => $paramAceite
            );
            $response->addDataSet(new DataSet('data', $dataset));
        } catch (\Exception $e) {
		    $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
	}
	
	public function authOperConfirmaTermo(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        try{
            $this->entityManager->beginTransaction();
			$operadorAutorizado = $this->service->validatePassword($row['OPERADORLOGADO'], $row['SENHA']);
			if($operadorAutorizado){
			    $this->service->insertAceitePedCol($row);
                $this->serviceEmail->enviaEmailTermoAceite($row, $response);
                $this->service->alteraStatus($row, 'C');
			}
			$this->entityManager->commit();
		} catch (\Exception $e) {
		    $this->entityManager->rollback();
			$response->setError(new Error($e->getMessage(), 1));
		}
    }
	
}